clear
use FivaRonning2008.dta
log using FivaRonning2008.txt, replace text

********************************************************************************
************APPLYING THE METHOD OF HANUSHEK, RIVKIN,TAYLOR (1996)***************
********************************************************************************
gen variance=se^2
//we first estimate eq x using ordinary least squares
reg kf dptax timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y

//storing the residuals
predict residuals if e(sample), resid
//g residuals=@res (tsp)
g residuals_sq=residuals^2

//regress the square of the residuals on the sampling variance of kf
reg residuals_sq variance

predict fitted_residuals_sq if e(sample)
//fitted_residuals_sq=@fit (tsp)
g inv_variance=fitted_residuals_sq^-1
sum fitted_residuals_sq

//use the inverse of the predicted square of residuals from this auxiliary regression as the weight in the GLS of eq X
reg kf dptax timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]  
predict residuals_ols if e(sample), resid

******************************************************************************** 
****************** INSTRUMENT VARIABLE GLS *************************************
********************************************************************************

********************************************************************************
****************** FIRST STAGE (TABLE 3) ***************************************
********************************************************************************

reg dptax by1911_1995 timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y
reg dptax rural timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y
reg dptax by1911_1995 rural timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y

********************************************************************************
****************** SECOND STAGE (TABLE 4) ***************************************
********************************************************************************

reg kf dptax timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=by1911_1995) timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=rural) timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=by1911_1995 rural) timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]

********************************************************************************
****************** SENSITIVITY (TABLE 5) ***************************************
********************************************************************************

ivreg kf (dptax=by1911_1995 rural) bugr615 reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=by1911_1995 rural) reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
gen thXtz=timlaer*reisetid/100
ivreg kf (dptax=by1911_1995 rural) timlaer reisetid thXtz enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
gen enrollXth=timlaer*enroll/1000
gen enroll2Xth=timlaer*enroll2/1000
ivreg kf (dptax=by1911_1995 rural) timlaer reisetid enroll enroll2 enrollXth enroll2Xth lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]

********************************************************************************
****************** SPATIAL LAG (TABLE 6) ***************************************
********************************************************************************

********************************************************************************
************APPLYING THE METHOD OF HANUSHEK, RIVKIN,TAYLOR (1996)***************
********************************************************************************

drop *residuals* inv_variance 

//we first estimate eq x using ordinary least squares
reg kf dptax w_kf_rsue timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y

//storing the residuals
predict residuals if e(sample), resid
//g residuals=@res (tsp)
g residuals_sq=residuals^2

//regress the square of the residuals on the sampling variance of kf
reg residuals_sq variance

predict fitted_residuals_sq if e(sample)
//fitted_residuals_sq=@fit (tsp)
g inv_variance=fitted_residuals_sq^-1
sum fitted_residuals_sq

//use the inverse of the predicted square of residuals from this auxiliary regression as the weight in the GLS of eq X
reg kf dptax w_kf_rsue timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]  
predict residuals_ols if e(sample), resid

reg kf dptax w_kf_rsue timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=by1911_1995) w_kf_rsue timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=rural) w_kf_rsue timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]
ivreg kf (dptax=by1911_1995 rural) w_kf_rsue timlaer reisetid enroll enroll2 lnpop expir lowersec uppersec unempl divorce y [aw=inv_variance]

log close
